
// Receiver Code 1101
#include <Arduino.h>
#include <esp_now.h>
#include <WiFi.h>
#include <Adafruit_NeoPixel.h>

// LED Strip Pin and Number of LEDs
#define LED_PIN D6
#define LED_COUNT 11  // Adjust to match your strip length

// Struct to receive more complex data
struct MessageData {
  bool highPressure;
};

// Create NeoPixel strip object
Adafruit_NeoPixel strip(LED_COUNT, LED_PIN, NEO_GRB + NEO_KHZ800);

// Updated callback function signature
void OnDataRecv(const esp_now_recv_info_t *recv_info, const uint8_t *incomingData, int len) {
  // Debugging: print received data details
  Serial.println("Data Received!");
  Serial.print("Length: ");
  Serial.println(len);
  
  // Verify data size matches expected struct
  if (len != sizeof(MessageData)) {
    Serial.println("Received incorrect data size!");
    return;
  }
  
  MessageData receivedMsg;
  memcpy(&receivedMsg, incomingData, sizeof(receivedMsg));
  
  Serial.print("Received Pressure Status: ");
  Serial.println(receivedMsg.highPressure ? "High" : "Low");
  
  // Set strip color based on pressure
  if (receivedMsg.highPressure) {
    // Pink color
    Serial.println("Setting Strip to PINK");
    for(int i=0; i<strip.numPixels(); i++) {
      strip.setPixelColor(i, strip.Color(255, 20, 147)); // Deep Pink
    }
  } else {
    // Green color
    Serial.println("Setting Strip to GREEN");
    for(int i=0; i<strip.numPixels(); i++) {
      strip.setPixelColor(i, strip.Color(0, 255, 0)); // Bright Green
    }
  }
  
  // Update the strip to display the new color
  strip.show();
}

void setup() {
  Serial.begin(115200);
  delay(1000); // Give serial a moment to connect
  
  Serial.println("Receiver Device Starting...");
  
  // Initialize NeoPixel strip
  strip.begin();
  strip.show(); // Initialize all pixels to 'off'
  
  // Print out this device's MAC
  Serial.print("This Device's MAC: ");
  Serial.println(WiFi.macAddress());
  
  // Set device as a Wi-Fi Station
  WiFi.mode(WIFI_STA);
  
  // Init ESP-NOW
  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }
  
  // Register receive callback
  esp_now_register_recv_cb(OnDataRecv);
  
  Serial.println("ESP-NOW Initialization Complete");
}

void loop() {
  // Nothing needed in loop for receiver
}