// Sender Code
#include <Arduino.h>
#include <esp_now.h>
#include <WiFi.h>

// Receiver (LED) Xiao MAC Address - REPLACE WITH YOUR ACTUAL MAC ADDRESS
uint8_t receiverAddress[] = {0x48, 0x31, 0xB7, 0x3F, 0xC1, 0x9C};

// FSR Sensor Pin
const int FSR_PIN = D0;

// Struct to send more complex data
struct MessageData {
  bool highPressure;
};

// Callback when data is sent
void OnDataSent(const uint8_t *mac_addr, esp_now_send_status_t status) {
  Serial.println(status == ESP_NOW_SEND_SUCCESS ? 
    "Delivery Success" : "Delivery Fail");
  
  // Print out the MAC address of the recipient
  Serial.print("Sent to MAC: ");
  for (int i = 0; i < 6; i++) {
    Serial.print(mac_addr[i], HEX);
    if (i < 5) Serial.print(":");
  }
  Serial.println();
}

void setup() {
  Serial.begin(115200);
  delay(1000); // Give serial a moment to connect
  
  Serial.println("Sender Device Starting...");
  
  // Set device as a Wi-Fi Station
  WiFi.mode(WIFI_STA);
  
  // Print out this device's MAC
  Serial.print("This Device's MAC: ");
  Serial.println(WiFi.macAddress());
  
  // Init ESP-NOW
  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }
  
  // Register send callback
  esp_now_register_send_cb(OnDataSent);
  
  // Register peer
  esp_now_peer_info_t peerInfo;
  memcpy(peerInfo.peer_addr, receiverAddress, 6);
  peerInfo.channel = 0;  
  peerInfo.encrypt = false;
  
  if (esp_now_add_peer(&peerInfo) != ESP_OK) {
    Serial.println("Failed to add peer");
    return;
  }
  
  Serial.println("ESP-NOW Initialization Complete");
}

void loop() {
  // Read FSR sensor
  int fsrReading = analogRead(FSR_PIN);
  
  Serial.print("FSR Reading: ");
  Serial.println(fsrReading);
  
  // Prepare message
  MessageData msg;
  msg.highPressure = (fsrReading > 800);
  
  // Send signal to turn on LED
  esp_err_t result = esp_now_send(receiverAddress, (uint8_t *) &msg, sizeof(msg));
  
  if (result == ESP_OK) {
    Serial.println(msg.highPressure ? "Sending High Pressure Signal" : "Sending Low Pressure Signal");
  }
  else {
    Serial.println("Error sending the data");
  }
  
  delay(500); // Prevent rapid repeated sending
}